
==========================
BigLedger Python Project
==========================


    This Python Project provides all the libraries and implementations to interact with Akaun API. It serves as a platform / framework to


A longer description of your project goes here...



Note
====

This library contains the following packages:

* Akaun SDK
* PythonBot SDK
* PythonBot API (making use of Akaun SDK too)
* PythonBot Agent
* PythonBot CLI

